Freq.fit-class: S4 class for the frequentist estimation results
Description
S4 class for the frequentist estimation results
Slots
model- character 'OU' or 'CIR'
random- numeric 1, 2, or c(1,2)
fixed- numeric value of the fixed effect if there is one
gridf- matrix of values on which the estimated is done
mu- numeric MLE estimator for parametric approach
omega- numeric MLE estimator for parametric approach
cutoff- value of the cutoff if there is one
sigma2- numeric estimated value of $\sigma^2$
estimf.trunc- matrix estimator of the density of $\phi$ for the truncated estimateur of the random effects
estimphi.trunc- matrix truncated estimator of the random effects
index- index of the used trajectories
estimphi- matrix of the estimator of the random effects
estimf- estimator of the density of $\phi$
estim.fixed- estimator of the fixed parameter if option estim.fix = 1
estim.fix- 1 if the user asked for the estimation of fixed parameter
bic- numeric bic
aic- numeric aic
times- vector of observation times, storage of input variable
X- matrix of observations, storage of input variable