Learn R Programming

mixedsde (version 1.0)

pred,Bayes.fit-method: Bayesian prediction method for a class object Bayes.fit

Description

Bayesian prediction

Usage

"pred"(x, invariant = FALSE, level = 0.05, newwindow = FALSE, plot.pred = TRUE, plot.legend = TRUE, burnIn, thinning, only.interval = TRUE, sample.length = 500, cand.length = 100, trajectories = FALSE, ylim, xlab = "times", ylab = "X", col = 3, lwd = 2, ...)

Arguments

x
Bayes.fit class
invariant
logical(1), if TRUE, the initial value is from the invariant distribution $X_t~N(\alpha/\beta, \sigma^2/2\beta)$ for the OU and $X_t~\Gamma(2\alpha/\sigma^2, \sigma^2/2\beta)$ for the CIR process, if FALSE (default) X0 is fixed from the data starting points
level
alpha for the predicion intervals, default 0.05
newwindow
logical(1), if TRUE, a new window is opened for the plot
plot.pred
logical(1), if TRUE, the results are depicted grafically
plot.legend
logical(1), if TRUE, a legend is added to the plot
burnIn
optional, if missing, the proposed value of the mixedsde.fit function is taken
thinning
optional, if missing, the proposed value of the mixedsde.fit function is taken
only.interval
logical(1), if TRUE, only prediction intervals are calculated, much faster than sampling from the whole predictive distribution
sample.length
number of samples to be drawn from the predictive distribution, if only.interval = FALSE
cand.length
number of candidates for which the predictive density is calculated, i.e. the candidates to be drawn from
trajectories
logical(1), if TRUE, only trajectories are drawn from the point estimations instead of sampling from the predictive distribution, similar to the frequentist approach
ylim
optional
xlab
optional, default 'times'
ylab
optional, default 'X'
col
color for the prediction intervals, default 3
lwd
linewidth for the prediction intervals, default 3
...
optional plot parameters

References

Dion, C., Hermann, S. and Samson, A. (2016). Mixedsde: an R package to fit mixed stochastic differential equations.