Learn R Programming

mixedsde (version 1.0)

summary,Freq.fit-method: Short summary of the results of class object Freq.fit

Description

Method for the S4 class Freq.fit

Usage

"summary"(object)

Arguments

object
Freq.fit class

References

Dion, C., Hermann, S. and Samson, A. (2016). Mixedsde: an R package to fit mixed stochastic differential equations.