Bayes.fit-class: S4 class for the Bayesian estimation results
Description
S4 class for the Bayesian estimation results
Slots
sigma2- vector of posterior samples for $\sigma^2$
mu- matrix of posterior samples for $\mu$
omega- matrix of posterior samples for $\omega$
alpha- matrix of posterior samples for $\alpha$
beta- matrix of posterior samples for $\beta$
random- 1, 2 or c(1,2)
burnIn- proposal for the burn-in phase
thinning- proposal for the thinning rate
model- 'OU' or 'CIR'
prior- list of prior values, input variable or calculated by the first 10% of series
times- vector of observation times, storage of input variable
X- matrix of observations, storage of input variable
ind.4.prior- indices of series used for the prior parameter calculation, if prior knowledge is availabe it is set to M+1