Rdocumentation
powered by
Learn R Programming
mixedsde (version 1.0)
pred,Freq.fit-method: Prediction method for the Freq.fit class object
Description
Frequentist prediction
Usage
"pred"(x, invariant = 0, level = 0.05, newwindow = FALSE, plot.pred = TRUE, ...)
Arguments
x
Freq.fit class
invariant
1 if the initial value is from the invariant distribution, default X0 is fixed from Xtrue
level
alpha for the predicion intervals, default 0.05
newwindow
logical(1), if TRUE, a new window is opened for the plot
plot.pred
logical(1), if TRUE, the results are depicted grafically
...
optional plot parameters
References
Dion, C., Hermann, S. and Samson, A. (2016). Mixedsde: an R package to fit mixed stochastic differential equations.