summary,Bayes.fit-method: Short summary of the results of class object Bayes.fit
Description
Method for the S4 class Bayes.fit
Usage
"summary"(object, level = 0.05, burnIn, thinning)
References
Dion, C., Hermann, S. and Samson, A. (2016). Mixedsde: an R package to fit mixed stochastic differential equations.